rakuten

package
v1.10.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 15, 2026 License: OSL-3.0 Imports: 9 Imported by: 0

README

rakuten.tv

android

create Android 9 device

france

  1. S'inscrire (sign up)
  2. Votre adresse électronique (your e-mail address)
  3. password
  4. J’accepte les conditions d’utilisation (I accept the terms of use)
  5. Créez un compte (create an account)

sweden

smart proxy:

mitmproxy `
--mode upstream:http://se.smartproxy.com:20001 `
--upstream-auth USER:PASS
  1. Se gratis med annonser (watch for free with ads)
  2. Registrera dig (register yourself)
  3. Din e-postadress (your e-mail address)
  4. password
  5. Jag accepterar användningsvillkoren (I accept the terms of use)
  6. Skapa konto (create an account)

Documentation

Index

Constants

const DeviceID = "atvui40"

DeviceID is the default identifier used for requests.

Variables

var Player = struct {
	PlayReady PlayerType
	Widevine  PlayerType
}{
	PlayReady: DeviceID + ":DASH-CENC:PR",
	Widevine:  DeviceID + ":DASH-CENC:WVM",
}
var Quality = struct {
	FHD VideoQuality
	HD  VideoQuality
}{
	FHD: "FHD",
	HD:  "HD",
}

Functions

This section is empty.

Types

type AudioLanguage added in v1.10.7

type AudioLanguage struct {
	Id string `json:"id"`
}

type Dash added in v1.10.7

type Dash struct {
	Body []byte
	Url  *url.URL
}

type Movie added in v1.10.7

type Movie struct {
	Id         string // Matches "content_id" in URLs
	MarketCode string
}

func (*Movie) ParseURL added in v1.10.7

func (m *Movie) ParseURL(rawLink string) error

func (*Movie) Request added in v1.10.7

func (m *Movie) Request() (*VideoItem, error)

Request fetches movie details (GET).

func (*Movie) RequestStream added in v1.10.7

func (m *Movie) RequestStream(audioLanguage string, player PlayerType, quality VideoQuality) (*StreamData, error)

RequestStream requests the stream for this movie (POST). Arguments: audioLanguage, player, quality.

type PlayerType added in v1.10.7

type PlayerType string

PlayerType defines the allowed player types/DRM schemes.

type SeasonData added in v1.10.7

type SeasonData struct {
	Episodes []VideoItem `json:"episodes"`
}

type Stream added in v1.10.7

type Stream struct {
	AudioLanguages []AudioLanguage `json:"audio_languages"`
}

type StreamData added in v1.10.7

type StreamData struct {
	StreamInfos []struct {
		LicenseUrl string `json:"license_url"`
		Url        string `json:"url"`
	} `json:"stream_infos"`
}

func (*StreamData) Dash added in v1.10.7

func (s *StreamData) Dash() (*Dash, error)

func (StreamData) Widevine added in v1.10.7

func (s StreamData) Widevine(data []byte) ([]byte, error)

type StreamRequestPayload added in v1.10.7

type StreamRequestPayload struct {
	AudioQuality             string       `json:"audio_quality"`
	DeviceIdentifier         string       `json:"device_identifier"`
	DeviceSerial             string       `json:"device_serial"`
	SubtitleLanguage         string       `json:"subtitle_language"`
	VideoType                string       `json:"video_type"`
	Player                   PlayerType   `json:"player"`
	ClassificationId         int          `json:"classification_id"`
	ContentType              string       `json:"content_type"`
	DeviceStreamVideoQuality VideoQuality `json:"device_stream_video_quality"`
	AudioLanguage            string       `json:"audio_language"`
	ContentId                string       `json:"content_id"`
}

type TvShow added in v1.10.7

type TvShow struct {
	Id         string // Matches "tv_show_id" in URLs
	MarketCode string
}

func (*TvShow) ParseURL added in v1.10.7

func (t *TvShow) ParseURL(rawLink string) error

ParseURL attempts to parse a URL and populate the TvShow struct. Usage:

var t TvShow
err := t.ParseURL("https://rakuten.tv/...")

func (*TvShow) Request added in v1.10.7

func (t *TvShow) Request() (*TvShowData, error)

Request fetches TV show details like seasons (GET).

func (*TvShow) RequestSeason added in v1.10.7

func (t *TvShow) RequestSeason(seasonId string) (*SeasonData, error)

RequestSeason fetches episodes for a specific season (GET).

func (*TvShow) RequestStream added in v1.10.7

func (t *TvShow) RequestStream(episodeId string, audioLanguage string, player PlayerType, quality VideoQuality) (*StreamData, error)

RequestStream requests the stream for a specific Episode (POST). Arguments: episodeId, audioLanguage, player, quality.

type TvShowData added in v1.10.7

type TvShowData struct {
	Seasons []struct {
		Id string `json:"id"`
	} `json:"seasons"`
}

func (TvShowData) String added in v1.10.7

func (t TvShowData) String() string

type VideoItem added in v1.10.7

type VideoItem struct {
	Title       string      `json:"title"`
	Id          string      `json:"id"`
	ViewOptions ViewOptions `json:"view_options"`
}

func (*VideoItem) String added in v1.10.7

func (v *VideoItem) String() string

It returns the ID, Title, and a unique list of available audio languages.

type VideoQuality added in v1.10.7

type VideoQuality string

VideoQuality defines the allowed video qualities for streaming.

type ViewOptions added in v1.10.7

type ViewOptions struct {
	Private struct {
		Streams []Stream `json:"streams"`
	} `json:"private"`
}

Jump to